% Part of the scripts/datasets for generating Figure 5 in the 3DNA
% 2003 Nucleic Acids Research paper. Originally written in Matlab at
% around 2002, slightly revised to make it work in GNU Octave v3.2.4
% (http://www.gnu.org/software/octave/)

% 2012-09-06 -- Xiang-Jun Lu (http://x3dna.org)

function incl_xdsp
    A = get_pars('A-heli-pars.dat', 26, 85);
    B = get_pars('B-heli-pars.dat', 26, 85);
    T = get_pars('TA-heli-pars.dat', 26, 85);

    numA = length(A);
    numB = length(B);
    numT = length(T);
    aidx = 1:numA;
    bidx = numA + 1:numA + numB;
    tidx = numA + numB + 1:numA + numB + numT;
    
    x = [A(:,1); B(:,1); T(:,1)];        % X-displacement
    y = [A(:,4); B(:,4); T(:,4)];        % Inclination
    
    fprintf('X limits: %7.1f %7.1f\n', min(x), max(x));
    fprintf('Y limits: %7.1f %7.1f\n', min(y), max(y));
    
    % Incl-Xdsp scatter plot
    close
    fig = plot(x(aidx), y(aidx), 'ro', 'MarkerSize', 6);
    set(gcf, 'Position', [100, 100, 1400, 800])
    hold on
    plot(x(bidx), y(bidx), 'ko', 'MarkerSize', 6);
    plot(x(tidx), y(tidx), 'go', 'MarkerSize', 6);
    
    xlabel('X-displacement', 'FontName', 'Vera', 'FontSize', 18)
    ylabel('Inclination', 'FontName', 'Vera', 'FontSize', 18)
    set(gca, 'XTick', -8:2:4, 'YTick', -10:20:90, 'FontName', 'Vera', 'FontSize', 12)
    rx = [-8.5 4];
    ry = [-20 90];
    axis([rx ry])

    % Draw ellipses
    draw_ellipse([x(aidx) y(aidx)], rx, ry, 'r-')
    draw_ellipse([x(bidx) y(bidx)], rx, ry, 'k-')
    draw_ellipse([x(tidx) y(tidx)], rx, ry, 'g-')
    
    print -dpng incl_xdsp.png
