% Part of the scripts/datasets for generating Figure 5 in the 3DNA
% 2003 Nucleic Acids Research paper. Originally written in Matlab at
% around 2002, slightly revised to make it work in GNU Octave v3.2.4
% (http://www.gnu.org/software/octave/)

% 2012-09-06 -- Xiang-Jun Lu (http://x3dna.org)

function roll_slide
    A = get_pars('A-step-pars.dat', 26, 85);
    B = get_pars('B-step-pars.dat', 26, 85);
    T = get_pars('TA-step-pars.dat', 26, 85);
    
    numA = length(A);
    numB = length(B);
    numT = length(T);
    aidx = 1:numA;
    bidx = numA + 1:numA + numB;
    tidx = numA + numB + 1:numA + numB + numT;
    
    x = [A(:,2); B(:,2); T(:,2)];        % Slide
    y = [A(:,5); B(:,5); T(:,5)];        % Roll
    
    fprintf('X limits: %7.1f %7.1f\n', min(x), max(x));
    fprintf('Y limits: %7.1f %7.1f\n', min(y), max(y));
    
    % Roll-Slide scatter plot
    close
    fig = plot(x(aidx), y(aidx), 'ro', 'MarkerSize', 6);
    set(gcf, 'Position', [100, 100, 1400, 800])
    hold on
    plot(x(bidx), y(bidx), 'ko', 'MarkerSize', 6);
    plot(x(tidx), y(tidx), 'go', 'MarkerSize', 6);

    xlabel('Slide', 'FontName', 'Vera', 'FontSize', 18)
    ylabel('Roll', 'FontName', 'Vera', 'FontSize', 18)
    set(gca, 'XTick', -3:3, 'YTick', -10:10:30, 'FontName', 'Vera', 'FontSize', 12)
    rx = [-3 3];
    ry = [-15 32];
    axis([rx ry])
    
    % Draw ellipses
    draw_ellipse([x(aidx) y(aidx)], rx, ry, 'r-')
    draw_ellipse([x(bidx) y(bidx)], rx, ry, 'k-')
    draw_ellipse([x(tidx) y(tidx)], rx, ry, 'g-')
    
    print -dpng roll_slide.png
