% Part of the scripts/datasets for generating Figure 5 in the 3DNA
% 2003 Nucleic Acids Research paper. Originally written in Matlab at
% around 2002, slightly revised to make it work in GNU Octave v3.2.4
% (http://www.gnu.org/software/octave/)

% 2012-09-06 -- Xiang-Jun Lu (http://x3dna.org)

function zph_zp
    A = get_pars('A-zp-zph.dat', 26, 73);
    B = get_pars('B-zp-zph.dat', 26, 73);
    T = get_pars('TA-zp-zph.dat', 26, 73);
    
    numA = length(A);
    numB = length(B);
    numT = length(T);
    aidx = 1:numA;
    bidx = numA + 1:numA + numB;
    tidx = numA + numB + 1:numA + numB + numT;
    
    x = [A(:,3); B(:,3); T(:,3)];        % Zp
    y = [A(:,6); B(:,6); T(:,6)];        % ZpH
    
    fprintf('X limits: %7.1f %7.1f\n', min(x), max(x));
    fprintf('Y limits: %7.1f %7.1f\n', min(y), max(y));
    
    % ZpH-Zp scatter plot
    close
    fig = plot(x(aidx), y(aidx), 'ro', 'MarkerSize', 6);
    set(gcf, 'Position', [100, 100, 1400, 800])
    hold on
    plot(x(bidx), y(bidx), 'ko', 'MarkerSize', 6);
    plot(x(tidx), y(tidx), 'go', 'MarkerSize', 6);
    
    xlabel('Zp', 'FontName', 'Vera', 'FontSize', 18)
    ylabel('ZpH', 'FontName', 'Vera', 'FontSize', 18)
    set(gca, 'XTick', -3:3, 'YTick', -2:2:10, 'FontName', 'Vera', 'FontSize', 12)
    rx = [-2.5 3];
    ry = [-3 9.5];
    axis([-2.5 3 -3 9.5])

    % Draw ellipses
    draw_ellipse([x(aidx) y(aidx)], rx, ry, 'r-')
    draw_ellipse([x(bidx) y(bidx)], rx, ry, 'k-')
    draw_ellipse([x(tidx) y(tidx)], rx, ry, 'g-')
    
    % Draw the boundary lines
    plot([1.5 1.5], ry, 'k:')
    plot([0.5 0.5], [ry(1), 4.0], 'k:')
    plot([rx(1) 1.5], [4.0 4.0], 'k:')
    
    print -dpng zph_zp.png
